@@ -28,6 +28,7 @@
 #include <gtk/gtk.h>
 #include <hildon-im-plugin.h>
 #include <hildon-im-ui.h>
+#include <hildon/hildon.h>
 
 #define G_DEBUG_DISABLE 1
 #define BUTTON_HEIGHT 60
@@ -79,7 +80,7 @@ static const gchar** special_upper[] = {special_upper_0,
                                         special_upper_3, NULL};
 static const gchar* special_cn_0[] = {"1", "2", "3", "4", "5", "6", "7", "8", "9", "0", NULL};
 static const gchar* special_cn_1[] = {"《", "》", "（", "）", "【", "】", "‘", "’", "、", NULL};
-static const gchar* special_cn_2[] = {"“", "”", "：", "；", "—", "！", "？", NULL};
+static const gchar* special_cn_2[] = {"“", "”", "：", "；", "——", "！", "？", NULL};
 static const gchar* special_cn_3[] = {"～", "……", NULL};
 static const gchar** special_cn[] = {special_cn_0,
                                      special_cn_1,
@@ -478,10 +479,10 @@ hildon_im_fcitx_fkb_enable (HildonIMPlugin *plugin,gboolean init)
   if (window_is_new)
   {
     priv->window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
-    gtk_window_set_type_hint(GTK_WINDOW(priv->window), GDK_WINDOW_TYPE_HINT_DIALOG | GDK_WINDOW_TYPE_HINT_NOTIFICATION);
+    gtk_window_set_type_hint(GTK_WINDOW(priv->window), GDK_WINDOW_TYPE_HINT_DIALOG/* | GDK_WINDOW_TYPE_HINT_NOTIFICATION*/);
     gtk_window_fullscreen(GTK_WINDOW (priv->window));
-    /*gtk_window_set_decorated (GTK_WINDOW (priv->window), FALSE);
-    gtk_window_set_default_size(GTK_WINDOW(priv->window),800,480);
+    gtk_window_set_decorated (GTK_WINDOW (priv->window), FALSE);
+    /*gtk_window_set_default_size(GTK_WINDOW(priv->window),800,480);
     g_signal_connect(priv->window, "destroy", G_CALLBACK(close_fkb), self);*/
   }
   hildon_im_ui_send_communication_message(priv->ui,
@@ -626,9 +627,11 @@ static void show_candwords(HildonIMFcitxFKBPrivate *priv)
     g_strlcat(wd,(const gchar *)(&strFindString),-1);
     gtk_button_set_label(GTK_BUTTON(priv->buttons[1][9]),(const gchar *)wd);
     gtk_widget_show(GTK_WIDGET(priv->buttons[3][2]));
+    gtk_button_set_label(GTK_BUTTON(priv->symbols_button),"翻页");
   }else{
     gtk_button_set_label(GTK_BUTTON(priv->buttons[1][9])," ");
     gtk_widget_hide(GTK_WIDGET(priv->buttons[3][2]));
+    gtk_button_set_label(GTK_BUTTON(priv->symbols_button),"符");
     return;
   }
   PYGetCandText(0,wd);
@@ -1045,9 +1048,12 @@ populate_window (HildonIMFcitxFKB *self)
   gint button_width = gdk_screen_width() / 10;
   gint fix_height = (button_width == 80)? 0:30;
   gchar *fontname = "Nokia Sans 24";
-  if(button_width == 48) fontname = "Nokia Sans 20";
-  PangoFontDescription *font = pango_font_description_from_string(fontname);
   priv = HILDON_IM_FCITX_FKB_GET_PRIVATE(self);
+  if(button_width == 48){
+    fontname = "Nokia Sans 20";
+    hildon_gtk_window_set_portrait_flags (GTK_WINDOW (priv->window), HILDON_PORTRAIT_MODE_REQUEST);
+  }
+  PangoFontDescription *font = pango_font_description_from_string(fontname);
   priv->vbox = gtk_vbox_new(FALSE, 1);
 
   priv->buttons[1][9] = gtk_button_new();
@@ -1067,11 +1073,15 @@ populate_window (HildonIMFcitxFKB *self)
                          G_CALLBACK(textview_button_release_cb), self);
 
   GtkWidget *menu = gtk_menu_new();
+  GtkWidget *separator1 = gtk_separator_menu_item_new();
+  GtkWidget *separator2 = gtk_separator_menu_item_new();
   GtkWidget *copy_item = gtk_menu_item_new_with_label("复制");
   GtkWidget *cut_item = gtk_menu_item_new_with_label("剪切");
   GtkWidget *paste_item = gtk_menu_item_new_with_label("粘贴");
   gtk_menu_shell_append(GTK_MENU_SHELL(menu), copy_item);
+  gtk_menu_shell_append(GTK_MENU_SHELL(menu), separator1);
   gtk_menu_shell_append(GTK_MENU_SHELL(menu), cut_item);
+  gtk_menu_shell_append(GTK_MENU_SHELL(menu), separator2);
   gtk_menu_shell_append(GTK_MENU_SHELL(menu), paste_item);
   g_signal_connect(G_OBJECT(copy_item), "activate",
                          G_CALLBACK(textview_copy), self);
@@ -1181,7 +1191,7 @@ populate_window (HildonIMFcitxFKB *self)
   }
   gtk_container_add (GTK_CONTAINER(priv->window), priv->vbox);
   pango_font_description_free(font);
-  font = pango_font_description_from_string("Nokia Sans 36");
+  font = pango_font_description_from_string("Nokia Sans 32");
   gtk_widget_modify_font(GTK_WIDGET(GTK_BIN(copy_item)->child),font);
   gtk_widget_modify_font(GTK_WIDGET(GTK_BIN(cut_item)->child),font);
   gtk_widget_modify_font(GTK_WIDGET(GTK_BIN(paste_item)->child),font);
